<?php

defined('ABSPATH') || exit;

class SCB_Helpers {
    const SECTION_NAME	= 'scb-options';

	public static function load_translations(){
		load_plugin_textdomain('simplecountryblock', FALSE, basename(__DIR__) . '/languages');
	}

    public static function get_blocked_countries(){
		$block_list = get_option(self::SECTION_NAME);
		if( !is_array($block_list) ){
			$block_list = array();
		}
		
		/**
		 * Filters the array that contains the codes of the blocked countries.
		 */
		return apply_filters('scb_blocked_countries', $block_list);
    }
    
    public static function is_blocked_country( string $country_code ){
		$blocked_countries = self::get_blocked_countries();
		$blocked_countries = array_flip($blocked_countries);

		/**
		 * Filters the result of the function. It should return either TRUE or FALSE.
		 */
		return apply_filters('scb_is_blocked_country', isset($blocked_countries[$country_code]), $country_code);
	}
	
	public static function maybe_block_visitor(){
		$client_data = new SCB_Visitor_Info($_SERVER['REMOTE_ADDR']);
		$country_code = $client_data->get_country_code();

		/**
		 * Can short-circuit the blocking of an client based on its IP, regardless if it is to be
		 * blocked by country.
		 * 
		 * Useful if there is a need for a whitelist.
		 */
		if( apply_filters('scb_prevent_client_blocking', FALSE, $_SERVER['REMOTE_ADDR']) ){
			return;
		}
	
		if( SCB_Helpers::is_blocked_country(($country_code)) ){
			/**
			 * Fires just before blocking a visitor based on its country.
			 */
			do_action('scb_before_client_block', $_SERVER['REMOTE_ADDR'], $client_data);

			http_response_code(403);
			die();
		}
	}
    
    /**
	 * This list is from:
	 * @link    https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2
	 */
	public static function get_country_list(){
		return array(
			'AD' => __('Andorra', 'simplecountryblock'),
			'AE' => __('United Arab Emirates', 'simplecountryblock'),
			'AF' => __('Afghanistan', 'simplecountryblock'),
			'AG' => __('Antigua and Barbuda', 'simplecountryblock'),
			'AI' => __('Anguilla', 'simplecountryblock'),
			'AL' => __('Albania', 'simplecountryblock'),
			'AM' => __('Armenia', 'simplecountryblock'),
			'AO' => __('Angola', 'simplecountryblock'),
			'AQ' => __('Antarctica', 'simplecountryblock'),
			'AR' => __('Argentina', 'simplecountryblock'),
			'AS' => __('American Samoa', 'simplecountryblock'),
			'AT' => __('Austria', 'simplecountryblock'),
			'AU' => __('Australia', 'simplecountryblock'),
			'AW' => __('Aruba', 'simplecountryblock'),
			'AX' => __('Åland Islands', 'simplecountryblock'),
			'AZ' => __('Azerbaijan', 'simplecountryblock'),
			'BA' => __('Bosnia and Herzegovina', 'simplecountryblock'),
			'BB' => __('Barbados', 'simplecountryblock'),
			'BD' => __('Bangladesh', 'simplecountryblock'),
			'BE' => __('Belgium', 'simplecountryblock'),
			'BF' => __('Burkina Faso', 'simplecountryblock'),
			'BG' => __('Bulgaria', 'simplecountryblock'),
			'BH' => __('Bahrain', 'simplecountryblock'),
			'BI' => __('Burundi', 'simplecountryblock'),
			'BJ' => __('Benin', 'simplecountryblock'),
			'BL' => __('Saint Barthélemy', 'simplecountryblock'),
			'BM' => __('Bermuda', 'simplecountryblock'),
			'BN' => __('Brunei Darussalam', 'simplecountryblock'),
			'BO' => __('Bolivia (Plurinational State of)', 'simplecountryblock'),
			'BQ' => __('Bonaire, Sint Eustatius and Saba', 'simplecountryblock'),
			'BR' => __('Brazil', 'simplecountryblock'),
			'BS' => __('Bahamas', 'simplecountryblock'),
			'BT' => __('Bhutan', 'simplecountryblock'),
			'BV' => __('Bouvet Island', 'simplecountryblock'),
			'BW' => __('Botswana', 'simplecountryblock'),
			'BY' => __('Belarus', 'simplecountryblock'),
			'BZ' => __('Belize', 'simplecountryblock'),
			'CA' => __('Canada', 'simplecountryblock'),
			'CC' => __('Cocos (Keeling) Islands', 'simplecountryblock'),
			'CD' => __('Congo, Democratic Republic of the', 'simplecountryblock'),
			'CF' => __('Central African Republic', 'simplecountryblock'),
			'CG' => __('Congo', 'simplecountryblock'),
			'CH' => __('Switzerland', 'simplecountryblock'),
			'CI' => __('Côte d\'Ivoire', 'simplecountryblock'),
			'CK' => __('Cook Islands', 'simplecountryblock'),
			'CL' => __('Chile', 'simplecountryblock'),
			'CM' => __('Cameroon', 'simplecountryblock'),
			'CN' => __('China', 'simplecountryblock'),
			'CO' => __('Colombia', 'simplecountryblock'),
			'CR' => __('Costa Rica', 'simplecountryblock'),
			'CU' => __('Cuba', 'simplecountryblock'),
			'CV' => __('Cabo Verde', 'simplecountryblock'),
			'CW' => __('Curaçao', 'simplecountryblock'),
			'CX' => __('Christmas Island', 'simplecountryblock'),
			'CY' => __('Cyprus', 'simplecountryblock'),
			'CZ' => __('Czechia', 'simplecountryblock'),
			'DE' => __('Germany', 'simplecountryblock'),
			'DJ' => __('Djibouti', 'simplecountryblock'),
			'DK' => __('Denmark', 'simplecountryblock'),
			'DM' => __('Dominica', 'simplecountryblock'),
			'DO' => __('Dominican Republic', 'simplecountryblock'),
			'DZ' => __('Algeria', 'simplecountryblock'),
			'EC' => __('Ecuador', 'simplecountryblock'),
			'EE' => __('Estonia', 'simplecountryblock'),
			'EG' => __('Egypt', 'simplecountryblock'),
			'EH' => __('Western Sahara', 'simplecountryblock'),
			'ER' => __('Eritrea', 'simplecountryblock'),
			'ES' => __('Spain', 'simplecountryblock'),
			'ET' => __('Ethiopia', 'simplecountryblock'),
			'FI' => __('Finland', 'simplecountryblock'),
			'FJ' => __('Fiji', 'simplecountryblock'),
			'FK' => __('Falkland Islands (Malvinas)', 'simplecountryblock'),
			'FM' => __('Micronesia (Federated States of)', 'simplecountryblock'),
			'FO' => __('Faroe Islands', 'simplecountryblock'),
			'FR' => __('France', 'simplecountryblock'),
			'GA' => __('Gabon', 'simplecountryblock'),
			'GB' => __('United Kingdom of Great Britain and Northern Ireland', 'simplecountryblock'),
			'GD' => __('Grenada', 'simplecountryblock'),
			'GE' => __('Georgia', 'simplecountryblock'),
			'GF' => __('French Guiana', 'simplecountryblock'),
			'GG' => __('Guernsey', 'simplecountryblock'),
			'GH' => __('Ghana', 'simplecountryblock'),
			'GI' => __('Gibraltar', 'simplecountryblock'),
			'GL' => __('Greenland', 'simplecountryblock'),
			'GM' => __('Gambia', 'simplecountryblock'),
			'GN' => __('Guinea', 'simplecountryblock'),
			'GP' => __('Guadeloupe', 'simplecountryblock'),
			'GQ' => __('Equatorial Guinea', 'simplecountryblock'),
			'GR' => __('Greece', 'simplecountryblock'),
			'GS' => __('South Georgia and the South Sandwich Islands', 'simplecountryblock'),
			'GT' => __('Guatemala', 'simplecountryblock'),
			'GU' => __('Guam', 'simplecountryblock'),
			'GW' => __('Guinea-Bissau', 'simplecountryblock'),
			'GY' => __('Guyana', 'simplecountryblock'),
			'HK' => __('Hong Kong', 'simplecountryblock'),
			'HM' => __('Heard Island and McDonald Islands', 'simplecountryblock'),
			'HN' => __('Honduras', 'simplecountryblock'),
			'HR' => __('Croatia', 'simplecountryblock'),
			'HT' => __('Haiti', 'simplecountryblock'),
			'HU' => __('Hungary', 'simplecountryblock'),
			'ID' => __('Indonesia', 'simplecountryblock'),
			'IE' => __('Ireland', 'simplecountryblock'),
			'IL' => __('Israel', 'simplecountryblock'),
			'IM' => __('Isle of Man', 'simplecountryblock'),
			'IN' => __('India', 'simplecountryblock'),
			'IO' => __('British Indian Ocean Territory', 'simplecountryblock'),
			'IQ' => __('Iraq', 'simplecountryblock'),
			'IR' => __('Iran (Islamic Republic of)', 'simplecountryblock'),
			'IS' => __('Iceland', 'simplecountryblock'),
			'IT' => __('Italy', 'simplecountryblock'),
			'JE' => __('Jersey', 'simplecountryblock'),
			'JM' => __('Jamaica', 'simplecountryblock'),
			'JO' => __('Jordan', 'simplecountryblock'),
			'JP' => __('Japan', 'simplecountryblock'),
			'KE' => __('Kenya', 'simplecountryblock'),
			'KG' => __('Kyrgyzstan', 'simplecountryblock'),
			'KH' => __('Cambodia', 'simplecountryblock'),
			'KI' => __('Kiribati', 'simplecountryblock'),
			'KM' => __('Comoros', 'simplecountryblock'),
			'KN' => __('Saint Kitts and Nevis', 'simplecountryblock'),
			'KP' => __('Korea (Democratic People\'s Republic of)', 'simplecountryblock'),
			'KR' => __('Korea, Republic of', 'simplecountryblock'),
			'KW' => __('Kuwait', 'simplecountryblock'),
			'KY' => __('Cayman Islands', 'simplecountryblock'),
			'KZ' => __('Kazakhstan', 'simplecountryblock'),
			'LA' => __('Lao People\'s Democratic Republic', 'simplecountryblock'),
			'LB' => __('Lebanon', 'simplecountryblock'),
			'LC' => __('Saint Lucia', 'simplecountryblock'),
			'LI' => __('Liechtenstein', 'simplecountryblock'),
			'LK' => __('Sri Lanka', 'simplecountryblock'),
			'LR' => __('Liberia', 'simplecountryblock'),
			'LS' => __('Lesotho', 'simplecountryblock'),
			'LT' => __('Lithuania', 'simplecountryblock'),
			'LU' => __('Luxembourg', 'simplecountryblock'),
			'LV' => __('Latvia', 'simplecountryblock'),
			'LY' => __('Libya', 'simplecountryblock'),
			'MA' => __('Morocco', 'simplecountryblock'),
			'MC' => __('Monaco', 'simplecountryblock'),
			'MD' => __('Moldova, Republic of', 'simplecountryblock'),
			'ME' => __('Montenegro', 'simplecountryblock'),
			'MF' => __('Saint Martin (French part)', 'simplecountryblock'),
			'MG' => __('Madagascar', 'simplecountryblock'),
			'MH' => __('Marshall Islands', 'simplecountryblock'),
			'MK' => __('North Macedonia', 'simplecountryblock'),
			'ML' => __('Mali', 'simplecountryblock'),
			'MM' => __('Myanmar', 'simplecountryblock'),
			'MN' => __('Mongolia', 'simplecountryblock'),
			'MO' => __('Macao', 'simplecountryblock'),
			'MP' => __('Northern Mariana Islands', 'simplecountryblock'),
			'MQ' => __('Martinique', 'simplecountryblock'),
			'MR' => __('Mauritania', 'simplecountryblock'),
			'MS' => __('Montserrat', 'simplecountryblock'),
			'MT' => __('Malta', 'simplecountryblock'),
			'MU' => __('Mauritius', 'simplecountryblock'),
			'MV' => __('Maldives', 'simplecountryblock'),
			'MW' => __('Malawi', 'simplecountryblock'),
			'MX' => __('Mexico', 'simplecountryblock'),
			'MY' => __('Malaysia', 'simplecountryblock'),
			'MZ' => __('Mozambique', 'simplecountryblock'),
			'NA' => __('Namibia', 'simplecountryblock'),
			'NC' => __('New Caledonia', 'simplecountryblock'),
			'NE' => __('Niger', 'simplecountryblock'),
			'NF' => __('Norfolk Island', 'simplecountryblock'),
			'NG' => __('Nigeria', 'simplecountryblock'),
			'NI' => __('Nicaragua', 'simplecountryblock'),
			'NL' => __('Netherlands', 'simplecountryblock'),
			'NO' => __('Norway', 'simplecountryblock'),
			'NP' => __('Nepal', 'simplecountryblock'),
			'NR' => __('Nauru', 'simplecountryblock'),
			'NU' => __('Niue', 'simplecountryblock'),
			'NZ' => __('New Zealand', 'simplecountryblock'),
			'OM' => __('Oman', 'simplecountryblock'),
			'PA' => __('Panama', 'simplecountryblock'),
			'PE' => __('Peru', 'simplecountryblock'),
			'PF' => __('French Polynesia', 'simplecountryblock'),
			'PG' => __('Papua New Guinea', 'simplecountryblock'),
			'PH' => __('Philippines', 'simplecountryblock'),
			'PK' => __('Pakistan', 'simplecountryblock'),
			'PL' => __('Poland', 'simplecountryblock'),
			'PM' => __('Saint Pierre and Miquelon', 'simplecountryblock'),
			'PN' => __('Pitcairn', 'simplecountryblock'),
			'PR' => __('Puerto Rico', 'simplecountryblock'),
			'PS' => __('Palestine, State of', 'simplecountryblock'),
			'PT' => __('Portugal', 'simplecountryblock'),
			'PW' => __('Palau', 'simplecountryblock'),
			'PY' => __('Paraguay', 'simplecountryblock'),
			'QA' => __('Qatar', 'simplecountryblock'),
			'RE' => __('Réunion', 'simplecountryblock'),
			'RO' => __('Romania', 'simplecountryblock'),
			'RS' => __('Serbia', 'simplecountryblock'),
			'RU' => __('Russian Federation', 'simplecountryblock'),
			'RW' => __('Rwanda', 'simplecountryblock'),
			'SA' => __('Saudi Arabia', 'simplecountryblock'),
			'SB' => __('Solomon Islands', 'simplecountryblock'),
			'SC' => __('Seychelles', 'simplecountryblock'),
			'SD' => __('Sudan', 'simplecountryblock'),
			'SE' => __('Sweden', 'simplecountryblock'),
			'SG' => __('Singapore', 'simplecountryblock'),
			'SH' => __('Saint Helena, Ascension and Tristan da Cunha', 'simplecountryblock'),
			'SI' => __('Slovenia', 'simplecountryblock'),
			'SJ' => __('Svalbard and Jan Mayen', 'simplecountryblock'),
			'SK' => __('Slovakia', 'simplecountryblock'),
			'SL' => __('Sierra Leone', 'simplecountryblock'),
			'SM' => __('San Marino', 'simplecountryblock'),
			'SN' => __('Senegal', 'simplecountryblock'),
			'SO' => __('Somalia', 'simplecountryblock'),
			'SR' => __('Suriname', 'simplecountryblock'),
			'SS' => __('South Sudan', 'simplecountryblock'),
			'ST' => __('Sao Tome and Principe', 'simplecountryblock'),
			'SV' => __('El Salvador', 'simplecountryblock'),
			'SX' => __('Sint Maarten (Dutch part)', 'simplecountryblock'),
			'SY' => __('Syrian Arab Republic', 'simplecountryblock'),
			'SZ' => __('Eswatini', 'simplecountryblock'),
			'TC' => __('Turks and Caicos Islands', 'simplecountryblock'),
			'TD' => __('Chad', 'simplecountryblock'),
			'TF' => __('French Southern Territories', 'simplecountryblock'),
			'TG' => __('Togo', 'simplecountryblock'),
			'TH' => __('Thailand', 'simplecountryblock'),
			'TJ' => __('Tajikistan', 'simplecountryblock'),
			'TK' => __('Tokelau', 'simplecountryblock'),
			'TL' => __('Timor-Leste', 'simplecountryblock'),
			'TM' => __('Turkmenistan', 'simplecountryblock'),
			'TN' => __('Tunisia', 'simplecountryblock'),
			'TO' => __('Tonga', 'simplecountryblock'),
			'TR' => __('Turkey', 'simplecountryblock'),
			'TT' => __('Trinidad and Tobago', 'simplecountryblock'),
			'TV' => __('Tuvalu', 'simplecountryblock'),
			'TW' => __('Taiwan, Province of China', 'simplecountryblock'),
			'TZ' => __('Tanzania, United Republic of', 'simplecountryblock'),
			'UA' => __('Ukraine', 'simplecountryblock'),
			'UG' => __('Uganda', 'simplecountryblock'),
			'UM' => __('United States Minor Outlying Islands', 'simplecountryblock'),
			'US' => __('United States of America', 'simplecountryblock'),
			'UY' => __('Uruguay', 'simplecountryblock'),
			'UZ' => __('Uzbekistan', 'simplecountryblock'),
			'VA' => __('Holy See', 'simplecountryblock'),
			'VC' => __('Saint Vincent and the Grenadines', 'simplecountryblock'),
			'VE' => __('Venezuela (Bolivarian Republic of)', 'simplecountryblock'),
			'VG' => __('Virgin Islands (British)', 'simplecountryblock'),
			'VI' => __('Virgin Islands (U.S.)', 'simplecountryblock'),
			'VN' => __('Viet Nam', 'simplecountryblock'),
			'VU' => __('Vanuatu', 'simplecountryblock'),
			'WF' => __('Wallis and Futuna', 'simplecountryblock'),
			'WS' => __('Samoa', 'simplecountryblock'),
			'YE' => __('Yemen', 'simplecountryblock'),
			'YT' => __('Mayotte', 'simplecountryblock'),
			'ZA' => __('South Africa', 'simplecountryblock'),
			'ZM' => __('Zambia', 'simplecountryblock'),
			'ZW' => __('Zimbabwe', 'simplecountryblock'),
		);
	}
}