<?php

defined('ABSPATH') || exit;

require 'vendor/autoload.php';

use GeoIp2\Database\Reader;
use GeoIp2\Exception\AddressNotFoundException;

class SCB_Visitor_Info {
	static private $database	= NULL;
	static private $errors		= NULL;
	public $record				= NULL;

	public static function init(){
		add_action('admin_notices', array(__CLASS__, 'display_notices'));

		self::$errors = new WP_Error();
	}

	public function __construct( string $ip_address = '' ){
		$status = self::maybe_load_database();

		if( is_wp_error($status) ){
			return FALSE;
		}

		if( !empty($ip_address) ){
			$status = $this->get_client_data($ip_address);

			if( is_wp_error($status) ){
				return FALSE;
			}
		}
	}

	public function get_client_data( string $ip_address ){
		try{
			$client_data = self::$database->country($ip_address);

			/**
			 * Filters the data obtained from the GeoIP2 Database before it is stored in the property.
			 */
			$this->record = apply_filters('scb_client_data', $client_data, $ip_address);
		} catch( AddressNotFoundException $error ){
			$this->record = NULL;

			self::$errors->add('address_not_found', __('IP Address not found in database.', 'simplecountryblock'));

			return self::$errors;
		}

		return $this->record;
	}

	public function get_country_code( string $ip_address = '' ){
		if( !empty($ip_address) ){
			$this->get_client_data($ip_address);
		}

		return $this->record->country->isoCode ?? FALSE;
	}

	public static function display_notices(){
		if( !current_user_can('manage_options') ){ return; }

		if( !empty(self::$errors->get_error_codes()) ){
			?>
			<div class="notice notice-error is-dismissible">
				<p><?php _e('The system found an error:', 'simplecountryblock'); ?></p>
				<ul>
					<li><?php
						echo implode('</li><li>', self::$errors->get_error_messages());
					?></li>
				</ul>
			</div>
			<?php
		}
	}

	private static function maybe_load_database(){
		if( !empty(self::$database) ){ return; }

		/**
		 * Filters the database filter for GeoIP2. Please provide a full path for the file.
		 */
		$geoip2_database = apply_filters('scb_geoip2_database', __DIR__ . '/vendor/database/GeoLite2-Country.mmdb');

		try {
			self::$database = new Reader($geoip2_database);
		} catch ( InvalidArgumentException $error ){
			self::$errors->add('database_exception', __('Unable to load database.', 'simplecountryblock'));

			return self::$errors;
		}

		return TRUE;
	}
}

SCB_Visitor_Info::init();